/*
 * Copyright (c) 1994 Cygnus Support.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms are permitted
 * provided that the above copyright notice and this paragraph are
 * duplicated in all such forms and that any documentation,
 * and/or other materials related to such
 * distribution and use acknowledge that the software was developed
 * at Cygnus Support, Inc.  Cygnus Support, Inc. may not be used to
 * endorse or promote products derived from this software without
 * specific prior written permission.
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */
#include "test.h"
 one_line_type gamma_vec[] = {
{ 1, 0,123,__LINE__, 0x3ff9444e, 0x16cd4267, 0xbff33333, 0x33333333},	/* 1.57918=f(-1.2)*/
{ 1, 0,123,__LINE__, 0x3ffa119e, 0xb1f65861, 0xbff30a3d, 0x70a3d70a},	/* 1.6293=f(-1.19)*/
{ 1, 0,123,__LINE__, 0x3ffaeb82, 0x968109fe, 0xbff2e147, 0xae147ae1},	/* 1.6825=f(-1.18)*/
{ 1, 0,123,__LINE__, 0x3ffbd343, 0x4abba0c2, 0xbff2b851, 0xeb851eb8},	/* 1.73908=f(-1.17)*/
{ 1, 0,123,__LINE__, 0x3ffcca67, 0x10d73f79, 0xbff28f5c, 0x28f5c28f},	/* 1.79941=f(-1.16)*/
{ 1, 0,123,__LINE__, 0x3ffdd2c0, 0x8c32209b, 0xbff26666, 0x66666666},	/* 1.86395=f(-1.15)*/
{ 1, 0,123,__LINE__, 0x3ffeee83, 0xcf3528db, 0xbff23d70, 0xa3d70a3d},	/* 1.93323=f(-1.14)*/
{ 1, 0,123,__LINE__, 0x40001031, 0x9d5bb189, 0xbff2147a, 0xe147ae14},	/* 2.00791=f(-1.13)*/
{ 1, 0,123,__LINE__, 0x4000b5db, 0xf942eba7, 0xbff1eb85, 0x1eb851eb},	/* 2.0888=f(-1.12)*/
{ 1, 0,123,__LINE__, 0x40016a5d, 0xfbc77523, 0xbff1c28f, 0x5c28f5c2},	/* 2.17694=f(-1.11)*/
{ 1, 0,123,__LINE__, 0x40023070, 0x04029610, 0xbff19999, 0x99999999},	/* 2.27365=f(-1.1)*/
{ 1, 0,123,__LINE__, 0x40030ba7, 0x734d2dd5, 0xbff170a3, 0xd70a3d70},	/* 2.38069=f(-1.09)*/
{ 1, 0,123,__LINE__, 0x400400df, 0x23f5d313, 0xbff147ae, 0x147ae147},	/* 2.50043=f(-1.08)*/
{ 1, 0,123,__LINE__, 0x400516e5, 0xffa5620d, 0xbff11eb8, 0x51eb851e},	/* 2.63618=f(-1.07)*/
{ 1, 0,123,__LINE__, 0x400657b5, 0x14dc3f15, 0xbff0f5c2, 0x8f5c28f5},	/* 2.79283=f(-1.06)*/
{ 1, 0,123,__LINE__, 0x4007d2c2, 0xf3ce0b66, 0xbff0cccc, 0xcccccccc},	/* 2.97791=f(-1.05)*/
{ 1, 0,123,__LINE__, 0x4009a1f7, 0xdd27653c, 0xbff0a3d7, 0x0a3d70a3},	/* 3.20409=f(-1.04)*/
{ 1, 0,123,__LINE__, 0x400bf5e5, 0x98e3c7f3, 0xbff07ae1, 0x47ae147a},	/* 3.49507=f(-1.03)*/
{ 1, 0,123,__LINE__, 0x400f3b97, 0x2b86f2f5, 0xbff051eb, 0x851eb851},	/* 3.9041=f(-1.02)*/
{ 1, 0,123,__LINE__, 0x40126780, 0x1dbd40cb, 0xbff028f5, 0xc28f5c28},	/* 4.60107=f(-1.01)*/
{ 6, 0,123,__LINE__, 0x40420596, 0x6f2b4f12, 0xbfefffff, 0xfffffffe},	/* 36.0437=f(-1)*/
{ 8, 0,123,__LINE__, 0x40127028, 0xb03a6b94, 0xbfefae14, 0x7ae147ac},	/* 4.60953=f(-0.99)*/
{ 8, 0,123,__LINE__, 0x400f5e39, 0x08ff9b9e, 0xbfef5c28, 0xf5c28f5a},	/* 3.92101=f(-0.98)*/
{ 9, 0,123,__LINE__, 0x400c29d7, 0x55dca5ee, 0xbfef0a3d, 0x70a3d708},	/* 3.52043=f(-0.97)*/
{ 9, 0,123,__LINE__, 0x4009e738, 0x34141044, 0xbfeeb851, 0xeb851eb6},	/* 3.2379=f(-0.96)*/
{ 9, 0,123,__LINE__, 0x40082950, 0x328185f1, 0xbfee6666, 0x66666664},	/* 3.02017=f(-0.95)*/
{ 9, 0,123,__LINE__, 0x4006bf8d, 0x1c708dc1, 0xbfee147a, 0xe147ae12},	/* 2.84353=f(-0.94)*/
{ 9, 0,123,__LINE__, 0x40059006, 0x445d00ff, 0xbfedc28f, 0x5c28f5c0},	/* 2.69532=f(-0.93)*/
{ 9, 0,123,__LINE__, 0x40048b44, 0xad1703ed, 0xbfed70a3, 0xd70a3d6e},	/* 2.568=f(-0.92)*/
{ 9, 0,123,__LINE__, 0x4003a74e, 0xdaf717d6, 0xbfed1eb8, 0x51eb851c},	/* 2.45669=f(-0.91)*/
{ 9, 0,123,__LINE__, 0x4002dd55, 0x76fc30f2, 0xbfeccccc, 0xccccccca},	/* 2.35807=f(-0.9)*/
{ 9, 0,123,__LINE__, 0x4002287d, 0x39483610, 0xbfec7ae1, 0x47ae1478},	/* 2.26977=f(-0.89)*/
{ 9, 0,123,__LINE__, 0x40018530, 0x52b52a99, 0xbfec28f5, 0xc28f5c26},	/* 2.19003=f(-0.88)*/
{ 9, 0,123,__LINE__, 0x4000f0b5, 0xf618bc4c, 0xbfebd70a, 0x3d70a3d4},	/* 2.11753=f(-0.87)*/
{ 9, 0,123,__LINE__, 0x400068f0, 0xb4a0633f, 0xbfeb851e, 0xb851eb82},	/* 2.05124=f(-0.86)*/
{ 9, 0,123,__LINE__, 0x3fffd867, 0x1b731e11, 0xbfeb3333, 0x33333330},	/* 1.99033=f(-0.85)*/
{ 9, 0,123,__LINE__, 0x3ffef249, 0xc3eafa86, 0xbfeae147, 0xae147ade},	/* 1.93415=f(-0.84)*/
{10, 0,123,__LINE__, 0x3ffe1d54, 0x717d8995, 0xbfea8f5c, 0x28f5c28c},	/* 1.88216=f(-0.83)*/
{10, 0,123,__LINE__, 0x3ffd57b3, 0xa141fbbe, 0xbfea3d70, 0xa3d70a3a},	/* 1.83391=f(-0.82)*/
{10, 0,123,__LINE__, 0x3ffc9fe0, 0x30a699ff, 0xbfe9eb85, 0x1eb851e8},	/* 1.78903=f(-0.81)*/
{10, 0,123,__LINE__, 0x3ffbf48f, 0xb8190964, 0xbfe99999, 0x99999996},	/* 1.74721=f(-0.8)*/
{10, 0,123,__LINE__, 0x3ffb54a8, 0xb8632048, 0xbfe947ae, 0x147ae144},	/* 1.70817=f(-0.79)*/
{10, 0,123,__LINE__, 0x3ffabf39, 0x893e68a6, 0xbfe8f5c2, 0x8f5c28f2},	/* 1.67169=f(-0.78)*/
{10, 0,123,__LINE__, 0x3ffa3371, 0x4cd9c4f7, 0xbfe8a3d7, 0x0a3d70a0},	/* 1.63756=f(-0.77)*/
{10, 0,123,__LINE__, 0x3ff9b09a, 0x64369154, 0xbfe851eb, 0x851eb84e},	/* 1.60562=f(-0.76)*/
{10, 0,123,__LINE__, 0x3ff93616, 0x060ea5d9, 0xbfe7ffff, 0xfffffffc},	/* 1.5757=f(-0.75)*/
{10, 0,123,__LINE__, 0x3ff8c358, 0xb3e0ee4c, 0xbfe7ae14, 0x7ae147aa},	/* 1.54769=f(-0.74)*/
{10, 0,123,__LINE__, 0x3ff857e7, 0x5ad8be34, 0xbfe75c28, 0xf5c28f58},	/* 1.52146=f(-0.73)*/
{10, 0,123,__LINE__, 0x3ff7f354, 0xfb15f9f4, 0xbfe70a3d, 0x70a3d706},	/* 1.49691=f(-0.72)*/
{10, 0,123,__LINE__, 0x3ff79540, 0xb913fefd, 0xbfe6b851, 0xeb851eb4},	/* 1.47394=f(-0.71)*/
{10, 0,123,__LINE__, 0x3ff73d54, 0x43a49164, 0xbfe66666, 0x66666662},	/* 1.45247=f(-0.7)*/
{10, 0,123,__LINE__, 0x3ff6eb42, 0x7de82fe1, 0xbfe6147a, 0xe147ae10},	/* 1.43244=f(-0.69)*/
{10, 0,123,__LINE__, 0x3ff69ec6, 0x605f1c15, 0xbfe5c28f, 0x5c28f5be},	/* 1.41376=f(-0.68)*/
{10, 0,123,__LINE__, 0x3ff657a2, 0x06f77725, 0xbfe570a3, 0xd70a3d6c},	/* 1.39639=f(-0.67)*/
{10, 0,123,__LINE__, 0x3ff6159d, 0xe41bab8e, 0xbfe51eb8, 0x51eb851a},	/* 1.38028=f(-0.66)*/
{10, 0,123,__LINE__, 0x3ff5d888, 0x1265759f, 0xbfe4cccc, 0xccccccc8},	/* 1.36536=f(-0.65)*/
{11, 0,123,__LINE__, 0x3ff5a033, 0xbfdd2269, 0xbfe47ae1, 0x47ae1476},	/* 1.35161=f(-0.64)*/
{11, 0,123,__LINE__, 0x3ff56c78, 0xaea940ca, 0xbfe428f5, 0xc28f5c24},	/* 1.33898=f(-0.63)*/
{11, 0,123,__LINE__, 0x3ff53d32, 0xc7da010d, 0xbfe3d70a, 0x3d70a3d2},	/* 1.32744=f(-0.62)*/
{11, 0,123,__LINE__, 0x3ff51241, 0xbd99748a, 0xbfe3851e, 0xb851eb80},	/* 1.31696=f(-0.61)*/
{11, 0,123,__LINE__, 0x3ff4eb88, 0xba882f44, 0xbfe33333, 0x3333332e},	/* 1.3075=f(-0.6)*/
{11, 0,123,__LINE__, 0x3ff4c8ee, 0x1c739085, 0xbfe2e147, 0xae147adc},	/* 1.29906=f(-0.59)*/
{11, 0,123,__LINE__, 0x3ff4aa5b, 0x38e59117, 0xbfe28f5c, 0x28f5c28a},	/* 1.29159=f(-0.58)*/
{11, 0,123,__LINE__, 0x3ff48fbc, 0x2a5186b4, 0xbfe23d70, 0xa3d70a38},	/* 1.28509=f(-0.57)*/
{11, 0,123,__LINE__, 0x3ff478ff, 0xa4d906c4, 0xbfe1eb85, 0x1eb851e6},	/* 1.27954=f(-0.56)*/
{11, 0,123,__LINE__, 0x3ff46616, 0xd1d27338, 0xbfe19999, 0x99999994},	/* 1.27492=f(-0.55)*/
{11, 0,123,__LINE__, 0x3ff456f5, 0x3161b92c, 0xbfe147ae, 0x147ae142},	/* 1.27123=f(-0.54)*/
{11, 0,123,__LINE__, 0x3ff44b90, 0x8194f02a, 0xbfe0f5c2, 0x8f5c28f0},	/* 1.26845=f(-0.53)*/
{11, 0,123,__LINE__, 0x3ff443e0, 0xaa931bc0, 0xbfe0a3d7, 0x0a3d709e},	/* 1.26657=f(-0.52)*/
{11, 0,123,__LINE__, 0x3ff43fdf, 0xaf8454c6, 0xbfe051eb, 0x851eb84c},	/* 1.26559=f(-0.51)*/
{11, 0,123,__LINE__, 0x3ff43f89, 0xa3f0edd6, 0xbfdfffff, 0xfffffff4},	/* 1.26551=f(-0.5)*/
{11, 0,123,__LINE__, 0x3ff442dc, 0xa56977bb, 0xbfdf5c28, 0xf5c28f50},	/* 1.26632=f(-0.49)*/
{11, 0,123,__LINE__, 0x3ff449d8, 0xd95c7fc7, 0xbfdeb851, 0xeb851eac},	/* 1.26803=f(-0.48)*/
{11, 0,123,__LINE__, 0x3ff45480, 0x6f110c79, 0xbfde147a, 0xe147ae08},	/* 1.27063=f(-0.47)*/
{12, 0,123,__LINE__, 0x3ff462d7, 0xa5cec4b2, 0xbfdd70a3, 0xd70a3d64},	/* 1.27413=f(-0.46)*/
{12, 0,123,__LINE__, 0x3ff474e4, 0xd74ed846, 0xbfdccccc, 0xccccccc0},	/* 1.27854=f(-0.45)*/
{12, 0,123,__LINE__, 0x3ff48ab0, 0x86a3b5a7, 0xbfdc28f5, 0xc28f5c1c},	/* 1.28386=f(-0.44)*/
{12, 0,123,__LINE__, 0x3ff4a445, 0x73d9e9a9, 0xbfdb851e, 0xb851eb78},	/* 1.29011=f(-0.43)*/
{12, 0,123,__LINE__, 0x3ff4c1b0, 0xb4aad44e, 0xbfdae147, 0xae147ad4},	/* 1.29729=f(-0.42)*/
{12, 0,123,__LINE__, 0x3ff4e301, 0xd2b2e116, 0xbfda3d70, 0xa3d70a30},	/* 1.30542=f(-0.41)*/
{12, 0,123,__LINE__, 0x3ff5084a, 0xefb983c8, 0xbfd99999, 0x9999998c},	/* 1.31452=f(-0.4)*/
{12, 0,123,__LINE__, 0x3ff531a0, 0xf0ba61c3, 0xbfd8f5c2, 0x8f5c28e8},	/* 1.32462=f(-0.39)*/
{12, 0,123,__LINE__, 0x3ff55f1b, 0xb0860c43, 0xbfd851eb, 0x851eb844},	/* 1.33572=f(-0.38)*/
{12, 0,123,__LINE__, 0x3ff590d6, 0x3aff1096, 0xbfd7ae14, 0x7ae147a0},	/* 1.34786=f(-0.37)*/
{12, 0,123,__LINE__, 0x3ff5c6ef, 0x122fdd12, 0xbfd70a3d, 0x70a3d6fc},	/* 1.36107=f(-0.36)*/
{12, 0,123,__LINE__, 0x3ff60188, 0x7eb98a6d, 0xbfd66666, 0x66666658},	/* 1.37537=f(-0.35)*/
{13, 0,123,__LINE__, 0x3ff640c8, 0xed6e320b, 0xbfd5c28f, 0x5c28f5b4},	/* 1.39082=f(-0.34)*/
{13, 0,123,__LINE__, 0x3ff684db, 0x5c4f3c48, 0xbfd51eb8, 0x51eb8510},	/* 1.40744=f(-0.33)*/
{13, 0,123,__LINE__, 0x3ff6cdef, 0xd9a661f9, 0xbfd47ae1, 0x47ae146c},	/* 1.42528=f(-0.32)*/
{13, 0,123,__LINE__, 0x3ff71c3c, 0x188e104f, 0xbfd3d70a, 0x3d70a3c8},	/* 1.44439=f(-0.31)*/
{13, 0,123,__LINE__, 0x3ff76ffc, 0x1f04dec5, 0xbfd33333, 0x33333324},	/* 1.46484=f(-0.3)*/
{13, 0,123,__LINE__, 0x3ff7c973, 0x12a46985, 0xbfd28f5c, 0x28f5c280},	/* 1.48668=f(-0.29)*/
{13, 0,123,__LINE__, 0x3ff828ec, 0x2a572886, 0xbfd1eb85, 0x1eb851dc},	/* 1.50999=f(-0.28)*/
{13, 0,123,__LINE__, 0x3ff88ebb, 0xcd09f2de, 0xbfd147ae, 0x147ae138},	/* 1.53485=f(-0.27)*/
{13, 0,123,__LINE__, 0x3ff8fb40, 0xe774b647, 0xbfd0a3d7, 0x0a3d7094},	/* 1.56134=f(-0.26)*/
{13, 0,123,__LINE__, 0x3ff96ee6, 0x85defb38, 0xbfcfffff, 0xffffffe0},	/* 1.58958=f(-0.25)*/
{13, 0,123,__LINE__, 0x3ff9ea25, 0xc276ba42, 0xbfceb851, 0xeb851e98},	/* 1.61966=f(-0.24)*/
{13, 0,123,__LINE__, 0x3ffa6d88, 0x1dc420a8, 0xbfcd70a3, 0xd70a3d50},	/* 1.65174=f(-0.23)*/
{13, 0,123,__LINE__, 0x3ffaf9aa, 0x5d7c3d05, 0xbfcc28f5, 0xc28f5c08},	/* 1.68595=f(-0.22)*/
{13, 0,123,__LINE__, 0x3ffb8f40, 0x172c5d09, 0xbfcae147, 0xae147ac0},	/* 1.72247=f(-0.21)*/
{14, 0,123,__LINE__, 0x3ffc2f18, 0x1909d547, 0xbfc99999, 0x99999978},	/* 1.7615=f(-0.2)*/
{14, 0,123,__LINE__, 0x3ffcda21, 0xf5485d67, 0xbfc851eb, 0x851eb830},	/* 1.80326=f(-0.19)*/
{14, 0,123,__LINE__, 0x3ffd9175, 0x0e457894, 0xbfc70a3d, 0x70a3d6e8},	/* 1.84801=f(-0.18)*/
{14, 0,123,__LINE__, 0x3ffe5659, 0xa7a36b38, 0xbfc5c28f, 0x5c28f5a0},	/* 1.89608=f(-0.17)*/
{14, 0,123,__LINE__, 0x3fff2a54, 0xb8982164, 0xbfc47ae1, 0x47ae1458},	/* 1.94783=f(-0.16)*/
{14, 0,123,__LINE__, 0x4000079b, 0xc876e0b7, 0xbfc33333, 0x33333310},	/* 2.00372=f(-0.15)*/
{14, 0,123,__LINE__, 0x4000839a, 0x7349ad7c, 0xbfc1eb85, 0x1eb851c8},	/* 2.06426=f(-0.14)*/
{15, 0,123,__LINE__, 0x40010a7e, 0xda580e24, 0xbfc0a3d7, 0x0a3d7080},	/* 2.13012=f(-0.13)*/
{15, 0,123,__LINE__, 0x40019df4, 0xd7eba8a6, 0xbfbeb851, 0xeb851e71},	/* 2.20213=f(-0.12)*/
{15, 0,123,__LINE__, 0x40024018, 0xafee144a, 0xbfbc28f5, 0xc28f5be2},	/* 2.2813=f(-0.11)*/
{16, 0,123,__LINE__, 0x4002f3a1, 0xffcc7857, 0xbfb99999, 0x99999953},	/* 2.36896=f(-0.1)*/
{16, 0,123,__LINE__, 0x4003bc25, 0x61e52dca, 0xbfb70a3d, 0x70a3d6c4},	/* 2.46687=f(-0.09)*/
{16, 0,123,__LINE__, 0x40049e7c, 0xe40bca84, 0xbfb47ae1, 0x47ae1435},	/* 2.57739=f(-0.08)*/
{16, 0,123,__LINE__, 0x4005a176, 0x9db946b2, 0xbfb1eb85, 0x1eb851a6},	/* 2.70384=f(-0.07)*/
{16, 0,123,__LINE__, 0x4006cf0a, 0xc552602d, 0xbfaeb851, 0xeb851e2d},	/* 2.85109=f(-0.06)*/
{17, 0,123,__LINE__, 0x400836af, 0x0cc9d6a8, 0xbfa99999, 0x9999990e},	/* 3.0267=f(-0.05)*/
{17, 0,123,__LINE__, 0x4009f24a, 0xd029f300, 0xbfa47ae1, 0x47ae13ef},	/* 3.24331=f(-0.04)*/
{17, 0,123,__LINE__, 0x400c326e, 0xec2b45d8, 0xbf9eb851, 0xeb851da0},	/* 3.52463=f(-0.03)*/
{18, 0,123,__LINE__, 0x400f6425, 0x732bd89a, 0xbf947ae1, 0x47ae1362},	/* 3.9239=f(-0.02)*/
{20, 0,123,__LINE__, 0x401271b0, 0x8923a63c, 0xbf847ae1, 0x47ae1249},	/* 4.61102=f(-0.01)*/
{64, 0,123,__LINE__, 0x40414837, 0x1bfcbfb9, 0x3cd19000, 0x00000000},	/* 34.5642=f(9.74915e-16)*/
{63, 0,123,__LINE__, 0x401265de, 0x0d9b3355, 0x3f847ae1, 0x47ae16ad},	/* 4.59948=f(0.01)*/
{64, 0,123,__LINE__, 0x400f34d8, 0xff85d9f2, 0x3f947ae1, 0x47ae1594},	/* 3.9008=f(0.02)*/
{64, 0,123,__LINE__, 0x400beb75, 0xf03c937b, 0x3f9eb851, 0xeb851fd2},	/* 3.48997=f(0.03)*/
{64, 0,123,__LINE__, 0x4009939d, 0xb8b8afe0, 0x3fa47ae1, 0x47ae1508},	/* 3.19708=f(0.04)*/
{64, 0,123,__LINE__, 0x4007c043, 0xbd12556a, 0x3fa99999, 0x99999a27},	/* 2.96888=f(0.05)*/
{64, 0,123,__LINE__, 0x400640d4, 0x945562ac, 0x3faeb851, 0xeb851f46},	/* 2.78166=f(0.06)*/
{64, 0,123,__LINE__, 0x4004fb66, 0x52da039c, 0x3fb1eb85, 0x1eb85232},	/* 2.62275=f(0.07)*/
{64, 0,123,__LINE__, 0x4003e080, 0xb2fb2a95, 0x3fb47ae1, 0x47ae14c1},	/* 2.48462=f(0.08)*/
{64, 0,123,__LINE__, 0x4002e628, 0xe5d72716, 0x3fb70a3d, 0x70a3d750},	/* 2.36238=f(0.09)*/
{63, 0,123,__LINE__, 0x4002058e, 0x35f3ded7, 0x3fb99999, 0x999999df},	/* 2.25271=f(0.1)*/
{63, 0,123,__LINE__, 0x400139d3, 0xf13aa1c2, 0x3fbc28f5, 0xc28f5c6e},	/* 2.15324=f(0.11)*/
{64, 0,123,__LINE__, 0x40007f62, 0xd2056320, 0x3fbeb851, 0xeb851efd},	/* 2.0622=f(0.12)*/
{64, 0,123,__LINE__, 0x3fffa701, 0x0fa52372, 0x3fc0a3d7, 0x0a3d70c6},	/* 1.97827=f(0.13)*/
{64, 0,123,__LINE__, 0x3ffe681c, 0x2612672c, 0x3fc1eb85, 0x1eb8520e},	/* 1.90042=f(0.14)*/
{64, 0,123,__LINE__, 0x3ffd3eb9, 0xa88055cd, 0x3fc33333, 0x33333356},	/* 1.82781=f(0.15)*/
{64, 0,123,__LINE__, 0x3ffc2822, 0xfcef3d6c, 0x3fc47ae1, 0x47ae149e},	/* 1.7598=f(0.16)*/
{64, 0,123,__LINE__, 0x3ffb221f, 0xb833c733, 0x3fc5c28f, 0x5c28f5e6},	/* 1.69583=f(0.17)*/
{63, 0,123,__LINE__, 0x3ffa2ad8, 0xbd071ce9, 0x3fc70a3d, 0x70a3d72e},	/* 1.63546=f(0.18)*/
{63, 0,123,__LINE__, 0x3ff940c3, 0x2c8551c2, 0x3fc851eb, 0x851eb876},	/* 1.57831=f(0.19)*/
{64, 0,123,__LINE__, 0x3ff86290, 0xbf25b60f, 0x3fc99999, 0x999999be},	/* 1.52406=f(0.2)*/
{64, 0,123,__LINE__, 0x3ff78f23, 0xf04c91ad, 0x3fcae147, 0xae147b06},	/* 1.47245=f(0.21)*/
{64, 0,123,__LINE__, 0x3ff6c586, 0xeaf64ce5, 0x3fcc28f5, 0xc28f5c4e},	/* 1.42322=f(0.22)*/
{64, 0,123,__LINE__, 0x3ff604e4, 0x7b353980, 0x3fcd70a3, 0xd70a3d96},	/* 1.37619=f(0.23)*/
{64, 0,123,__LINE__, 0x3ff54c82, 0x8064dd37, 0x3fceb851, 0xeb851ede},	/* 1.33118=f(0.24)*/
{64, 0,123,__LINE__, 0x3ff49bbd, 0x81c16ee7, 0x3fd00000, 0x00000013},	/* 1.28802=f(0.25)*/
{64, 0,123,__LINE__, 0x3ff3f205, 0x20fe465a, 0x3fd0a3d7, 0x0a3d70b7},	/* 1.24659=f(0.26)*/
{64, 0,123,__LINE__, 0x3ff34ed9, 0x388c2969, 0x3fd147ae, 0x147ae15b},	/* 1.20675=f(0.27)*/
{64, 0,123,__LINE__, 0x3ff2b1c7, 0x8012028d, 0x3fd1eb85, 0x1eb851ff},	/* 1.1684=f(0.28)*/
{64, 0,123,__LINE__, 0x3ff21a69, 0x9ad205bd, 0x3fd28f5c, 0x28f5c2a3},	/* 1.13145=f(0.29)*/
{64, 0,123,__LINE__, 0x3ff18863, 0x7a6c4184, 0x3fd33333, 0x33333347},	/* 1.0958=f(0.3)*/
{64, 0,123,__LINE__, 0x3ff0fb62, 0x0563466a, 0x3fd3d70a, 0x3d70a3eb},	/* 1.06137=f(0.31)*/
{64, 0,123,__LINE__, 0x3ff07319, 0xf4790096, 0x3fd47ae1, 0x47ae148f},	/* 1.0281=f(0.32)*/
{63, 0,123,__LINE__, 0x3fefde8d, 0xb984cef1, 0x3fd51eb8, 0x51eb8533},	/* 0.995917=f(0.33)*/
{63, 0,123,__LINE__, 0x3feedf54, 0xbcddcb8c, 0x3fd5c28f, 0x5c28f5d7},	/* 0.964762=f(0.34)*/
{63, 0,123,__LINE__, 0x3fede816, 0xe3c18e25, 0x3fd66666, 0x6666667b},	/* 0.934581=f(0.35)*/
{64, 0,123,__LINE__, 0x3fecf86b, 0x9becf7aa, 0x3fd70a3d, 0x70a3d71f},	/* 0.905325=f(0.36)*/
{63, 0,123,__LINE__, 0x3fec0ff2, 0xc6c099ab, 0x3fd7ae14, 0x7ae147c3},	/* 0.876947=f(0.37)*/
{63, 0,123,__LINE__, 0x3feb2e53, 0xd34840ae, 0x3fd851eb, 0x851eb867},	/* 0.849405=f(0.38)*/
{64, 0,123,__LINE__, 0x3fea533c, 0xf61ba0b9, 0x3fd8f5c2, 0x8f5c290b},	/* 0.822661=f(0.39)*/
{64, 0,123,__LINE__, 0x3fe97e62, 0x7a8f4a1f, 0x3fd99999, 0x999999af},	/* 0.796678=f(0.4)*/
{64, 0,123,__LINE__, 0x3fe8af7e, 0x2975c40d, 0x3fda3d70, 0xa3d70a53},	/* 0.771422=f(0.41)*/
{64, 0,123,__LINE__, 0x3fe7e64e, 0xc252abd7, 0x3fdae147, 0xae147af7},	/* 0.746864=f(0.42)*/
{63, 0,123,__LINE__, 0x3fe72297, 0x8465376e, 0x3fdb851e, 0xb851eb9b},	/* 0.722973=f(0.43)*/
{64, 0,123,__LINE__, 0x3fe6641f, 0xc55ac741, 0x3fdc28f5, 0xc28f5c3f},	/* 0.699722=f(0.44)*/
{63, 0,123,__LINE__, 0x3fe5aab2, 0x93d23543, 0x3fdccccc, 0xcccccce3},	/* 0.677087=f(0.45)*/
{64, 0,123,__LINE__, 0x3fe4f61e, 0x642115c4, 0x3fdd70a3, 0xd70a3d87},	/* 0.655044=f(0.46)*/
{64, 0,123,__LINE__, 0x3fe44634, 0xc6082a3c, 0x3fde147a, 0xe147ae2b},	/* 0.63357=f(0.47)*/
{63, 0,123,__LINE__, 0x3fe39aca, 0x223633e1, 0x3fdeb851, 0xeb851ecf},	/* 0.612645=f(0.48)*/
{63, 0,123,__LINE__, 0x3fe2f3b5, 0x7ea204c7, 0x3fdf5c28, 0xf5c28f73},	/* 0.59225=f(0.49)*/
{64, 0,123,__LINE__, 0x3fe250d0, 0x48e7a1a7, 0x3fe00000, 0x0000000b},	/* 0.572365=f(0.5)*/
{64, 0,123,__LINE__, 0x3fe1b1f6, 0x25f1b011, 0x3fe051eb, 0x851eb85d},	/* 0.552974=f(0.51)*/
{64, 0,123,__LINE__, 0x3fe11704, 0xc651449e, 0x3fe0a3d7, 0x0a3d70af},	/* 0.53406=f(0.52)*/
{64, 0,123,__LINE__, 0x3fe07fdb, 0xbebb3308, 0x3fe0f5c2, 0x8f5c2901},	/* 0.515608=f(0.53)*/
{63, 0,123,__LINE__, 0x3fdfd8b8, 0xc867d4a1, 0x3fe147ae, 0x147ae153},	/* 0.497603=f(0.54)*/
{63, 0,123,__LINE__, 0x3fdeb8d3, 0x57045cb5, 0x3fe19999, 0x999999a5},	/* 0.480031=f(0.55)*/
{63, 0,123,__LINE__, 0x3fdd9fd0, 0x171c2730, 0x3fe1eb85, 0x1eb851f7},	/* 0.462879=f(0.56)*/
{64, 0,123,__LINE__, 0x3fdc8d7a, 0xc4b9b5a6, 0x3fe23d70, 0xa3d70a49},	/* 0.446135=f(0.57)*/
{64, 0,123,__LINE__, 0x3fdb81a1, 0xb8c7e918, 0x3fe28f5c, 0x28f5c29b},	/* 0.429787=f(0.58)*/
{62, 0,123,__LINE__, 0x3fda7c15, 0xbbeb953e, 0x3fe2e147, 0xae147aed},	/* 0.413824=f(0.59)*/
{64, 0,123,__LINE__, 0x3fd97ca9, 0xdd244e01, 0x3fe33333, 0x3333333f},	/* 0.398234=f(0.6)*/
{63, 0,123,__LINE__, 0x3fd88333, 0x4bd4a434, 0x3fe3851e, 0xb851eb91},	/* 0.383008=f(0.61)*/
{64, 0,123,__LINE__, 0x3fd78f89, 0x34dcecc4, 0x3fe3d70a, 0x3d70a3e3},	/* 0.368136=f(0.62)*/
{64, 0,123,__LINE__, 0x3fd6a184, 0xa27d2eb7, 0x3fe428f5, 0xc28f5c35},	/* 0.353608=f(0.63)*/
{64, 0,123,__LINE__, 0x3fd5b900, 0x5ebb22ca, 0x3fe47ae1, 0x47ae1487},	/* 0.339417=f(0.64)*/
{64, 0,123,__LINE__, 0x3fd4d5d8, 0xd8107650, 0x3fe4cccc, 0xccccccd9},	/* 0.325552=f(0.65)*/
{63, 0,123,__LINE__, 0x3fd3f7ec, 0x082be647, 0x3fe51eb8, 0x51eb852b},	/* 0.312007=f(0.66)*/
{64, 0,123,__LINE__, 0x3fd31f19, 0x5c956618, 0x3fe570a3, 0xd70a3d7d},	/* 0.298773=f(0.67)*/
{62, 0,123,__LINE__, 0x3fd24b41, 0xa10a79ab, 0x3fe5c28f, 0x5c28f5cf},	/* 0.285843=f(0.68)*/
{63, 0,123,__LINE__, 0x3fd17c46, 0xeb6c4a78, 0x3fe6147a, 0xe147ae21},	/* 0.27321=f(0.69)*/
{63, 0,123,__LINE__, 0x3fd0b20c, 0x891cde54, 0x3fe66666, 0x66666673},	/* 0.260867=f(0.7)*/
{63, 0,123,__LINE__, 0x3fcfd8ed, 0xdb588aea, 0x3fe6b851, 0xeb851ec5},	/* 0.248808=f(0.71)*/
{63, 0,123,__LINE__, 0x3fce56d7, 0x4573432f, 0x3fe70a3d, 0x70a3d717},	/* 0.237025=f(0.72)*/
{62, 0,123,__LINE__, 0x3fccdda2, 0x71dd3cb8, 0x3fe75c28, 0xf5c28f69},	/* 0.225514=f(0.73)*/
{63, 0,123,__LINE__, 0x3fcb6d1e, 0x73fcbbc6, 0x3fe7ae14, 0x7ae147bb},	/* 0.214268=f(0.74)*/
{64, 0,123,__LINE__, 0x3fca051c, 0x372609b5, 0x3fe80000, 0x0000000d},	/* 0.203281=f(0.75)*/
{62, 0,123,__LINE__, 0x3fc8a56e, 0x662dfe52, 0x3fe851eb, 0x851eb85f},	/* 0.192549=f(0.76)*/
{63, 0,123,__LINE__, 0x3fc74de9, 0x5491a0f4, 0x3fe8a3d7, 0x0a3d70b1},	/* 0.182065=f(0.77)*/
{63, 0,123,__LINE__, 0x3fc5fe62, 0xe913a149, 0x3fe8f5c2, 0x8f5c2903},	/* 0.171826=f(0.78)*/
{63, 0,123,__LINE__, 0x3fc4b6b2, 0x89b32fef, 0x3fe947ae, 0x147ae155},	/* 0.161825=f(0.79)*/
{64, 0,123,__LINE__, 0x3fc376b1, 0x08e23fdc, 0x3fe99999, 0x999999a7},	/* 0.15206=f(0.8)*/
{64, 0,123,__LINE__, 0x3fc23e38, 0x93e37a8d, 0x3fe9eb85, 0x1eb851f9},	/* 0.142524=f(0.81)*/
{64, 0,123,__LINE__, 0x3fc10d24, 0xa23a398b, 0x3fea3d70, 0xa3d70a4b},	/* 0.133214=f(0.82)*/
{63, 0,123,__LINE__, 0x3fbfc6a3, 0xcc315b90, 0x3fea8f5c, 0x28f5c29d},	/* 0.124125=f(0.83)*/
{63, 0,123,__LINE__, 0x3fbd813c, 0x7b740cee, 0x3feae147, 0xae147aef},	/* 0.115253=f(0.84)*/
{63, 0,123,__LINE__, 0x3fbb49d1, 0x4b2fd375, 0x3feb3333, 0x33333341},	/* 0.106595=f(0.85)*/
{64, 0,123,__LINE__, 0x3fb92022, 0x56d7dd05, 0x3feb851e, 0xb851eb93},	/* 0.0981466=f(0.86)*/
{64, 0,123,__LINE__, 0x3fb703f1, 0xc3de06d7, 0x3febd70a, 0x3d70a3e5},	/* 0.0899039=f(0.87)*/
{63, 0,123,__LINE__, 0x3fb4f503, 0xaa939c82, 0x3fec28f5, 0xc28f5c37},	/* 0.0818636=f(0.88)*/
{64, 0,123,__LINE__, 0x3fb2f31e, 0x00542ac1, 0x3fec7ae1, 0x47ae1489},	/* 0.0740222=f(0.89)*/
{64, 0,123,__LINE__, 0x3fb0fe08, 0x82e4655d, 0x3feccccc, 0xccccccdb},	/* 0.0663762=f(0.9)*/
{64, 0,123,__LINE__, 0x3fae2b19, 0x49e1a3e3, 0x3fed1eb8, 0x51eb852d},	/* 0.0589226=f(0.91)*/
{63, 0,123,__LINE__, 0x3faa72ea, 0xf732ec51, 0x3fed70a3, 0xd70a3d7f},	/* 0.051658=f(0.92)*/
{64, 0,123,__LINE__, 0x3fa6d31f, 0x59f26461, 0x3fedc28f, 0x5c28f5d1},	/* 0.0445795=f(0.93)*/
{64, 0,123,__LINE__, 0x3fa34b52, 0xbf31777a, 0x3fee147a, 0xe147ae23},	/* 0.037684=f(0.94)*/
{63, 0,123,__LINE__, 0x3f9fb648, 0xaaf974c6, 0x3fee6666, 0x66666675},	/* 0.0309688=f(0.95)*/
{64, 0,123,__LINE__, 0x3f99046c, 0x1e32ca6b, 0x3feeb851, 0xeb851ec7},	/* 0.0244309=f(0.96)*/
{64, 0,123,__LINE__, 0x3f928059, 0x0b8e7465, 0x3fef0a3d, 0x70a3d719},	/* 0.0180677=f(0.97)*/
{64, 0,123,__LINE__, 0x3f8852bb, 0x7fbc7bc9, 0x3fef5c28, 0xf5c28f6b},	/* 0.0118765=f(0.98)*/
{64, 0,123,__LINE__, 0x3f77fb35, 0xb942dcc7, 0x3fefae14, 0x7ae147bd},	/* 0.00585481=f(0.99)*/
{63, 0,123,__LINE__, 0xbcd0297b, 0x5ce1bf4c, 0x3ff00000, 0x00000007},	/* -8.97173e-16=f(1)*/
{63, 0,123,__LINE__, 0xbf774eb8, 0x68854a94, 0x3ff028f5, 0xc28f5c30},	/* -0.00569031=f(1.01)*/
{64, 0,123,__LINE__, 0xbf86f9b8, 0x26415027, 0x3ff051eb, 0x851eb859},	/* -0.0112185=f(1.02)*/
{63, 0,123,__LINE__, 0xbf90fc24, 0xebca70f3, 0x3ff07ae1, 0x47ae1482},	/* -0.0165869=f(1.03)*/
{64, 0,123,__LINE__, 0xbf96521f, 0x9a6e8e80, 0x3ff0a3d7, 0x0a3d70ab},	/* -0.0217977=f(1.04)*/
{64, 0,123,__LINE__, 0xbf9b7f5f, 0x30c6fdd9, 0x3ff0cccc, 0xccccccd4},	/* -0.0268531=f(1.05)*/
{64, 0,123,__LINE__, 0xbfa04239, 0x800dd664, 0x3ff0f5c2, 0x8f5c28fd},	/* -0.0317553=f(1.06)*/
{64, 0,123,__LINE__, 0xbfa2b0f3, 0x5dde5138, 0x3ff11eb8, 0x51eb8526},	/* -0.0365063=f(1.07)*/
{63, 0,123,__LINE__, 0xbfa50c21, 0x4cf501ec, 0x3ff147ae, 0x147ae14f},	/* -0.0411082=f(1.08)*/
{63, 0,123,__LINE__, 0xbfa75405, 0xb99ffcc4, 0x3ff170a3, 0xd70a3d78},	/* -0.0455629=f(1.09)*/
{63, 0,123,__LINE__, 0xbfa988e1, 0x705d8a49, 0x3ff19999, 0x999999a1},	/* -0.0498724=f(1.1)*/
{63, 0,123,__LINE__, 0xbfabaaf3, 0xac344282, 0x3ff1c28f, 0x5c28f5ca},	/* -0.0540386=f(1.11)*/
{63, 0,123,__LINE__, 0xbfadba7a, 0x246a1f3c, 0x3ff1eb85, 0x1eb851f3},	/* -0.0580633=f(1.12)*/
{64, 0,123,__LINE__, 0xbfafb7b1, 0x19a30459, 0x3ff2147a, 0xe147ae1c},	/* -0.0619483=f(1.13)*/
{64, 0,123,__LINE__, 0xbfb0d169, 0xb1375bd8, 0x3ff23d70, 0xa3d70a45},	/* -0.0656954=f(1.14)*/
{64, 0,123,__LINE__, 0xbfb1be0d, 0x3ba6e2f4, 0x3ff26666, 0x6666666e},	/* -0.0693062=f(1.15)*/
{64, 0,123,__LINE__, 0xbfb2a1df, 0x3f1a2f12, 0x3ff28f5c, 0x28f5c297},	/* -0.0727825=f(1.16)*/
{63, 0,123,__LINE__, 0xbfb37cfb, 0x2ac8e161, 0x3ff2b851, 0xeb851ec0},	/* -0.0761258=f(1.17)*/
{63, 0,123,__LINE__, 0xbfb44f7b, 0xcf71448e, 0x3ff2e147, 0xae147ae9},	/* -0.0793378=f(1.18)*/
{63, 0,123,__LINE__, 0xbfb5197b, 0x6469c247, 0x3ff30a3d, 0x70a3d712},	/* -0.0824201=f(1.19)*/
{ 0, 0,123,__LINE__, 0xc016dfac, 0xa2f1859e, 0xc01921fb, 0x54442d18},	/* -5.71843=f(-6.28319)*/
{ 0, 0,123,__LINE__, 0xc00758af, 0x8d064209, 0xc012d97c, 0x7f3321d2},	/* -2.9183=f(-4.71239)*/
{ 9, 0,123,__LINE__, 0x3f8fe5e6, 0x72b2793b, 0xc00921fb, 0x54442d18},	/* 0.0155752=f(-3.14159)*/
{ 1, 0,123,__LINE__, 0x3feab00e, 0xd8258966, 0xbff921fb, 0x54442d18},	/* 0.833991=f(-1.5708)*/
{64, 0, 34,__LINE__, 0x7ff00000, 0x00000000, 0x00000000, 0x00000000},	/* inf=f(0)*/
{64, 0,123,__LINE__, 0xbfbdabdf, 0x1a1d104e, 0x3ff921fb, 0x54442d18},	/* -0.115904=f(1.5708)*/
{64, 0,123,__LINE__, 0x3fea7c79, 0x5ea35deb, 0x400921fb, 0x54442d18},	/* 0.827695=f(3.14159)*/
{64, 0,123,__LINE__, 0x400608aa, 0x8a8d8d2f, 0x4012d97c, 0x7f3321d2},	/* 2.75423=f(4.71239)*/
{64, 0, 34,__LINE__, 0x7ff00000, 0x00000000, 0xc03e0000, 0x00000000},	/* inf=f(-30)*/
{ 0, 0,123,__LINE__, 0xc050e289, 0x6cea7ba9, 0xc03c4ccc, 0xcccccccd},	/* -67.5396=f(-28.3)*/
{ 0, 0,123,__LINE__, 0xc04f0519, 0xeb4db9ec, 0xc03a9999, 0x9999999a},	/* -62.0399=f(-26.6)*/
{ 0, 0,123,__LINE__, 0xc04bae2f, 0xf3cea701, 0xc038e666, 0x66666667},	/* -55.3608=f(-24.9)*/
{ 0, 0,123,__LINE__, 0xc049480a, 0x58dbe614, 0xc0373333, 0x33333334},	/* -50.5628=f(-23.2)*/
{ 0, 0,123,__LINE__, 0xc046e33b, 0x5b354483, 0xc0358000, 0x00000001},	/* -45.7752=f(-21.5)*/
{ 0, 0,123,__LINE__, 0xc0440737, 0x06b0a6bc, 0xc033cccc, 0xccccccce},	/* -40.0564=f(-19.8)*/
{ 0, 0,123,__LINE__, 0xc0412f28, 0x3b574763, 0xc0321999, 0x9999999b},	/* -34.3684=f(-18.1)*/
{ 0, 0,123,__LINE__, 0xc03e9a68, 0xd4a14604, 0xc0306666, 0x66666668},	/* -30.6032=f(-16.4)*/
{ 0, 0,123,__LINE__, 0xc039b925, 0x28d21eed, 0xc02d6666, 0x6666666a},	/* -25.7232=f(-14.7)*/
{12, 0,123,__LINE__, 0x40240d2f, 0x9488a489, 0xc02a0000, 0x00000004},	/* 10.0258=f(-13)*/
{ 0, 0,123,__LINE__, 0xc030e1df, 0x9a7287e9, 0xc0269999, 0x9999999e},	/* -16.8823=f(-11.3)*/
{ 0, 0,123,__LINE__, 0xc029f3f9, 0x5353959b, 0xc0233333, 0x33333338},	/* -12.9765=f(-9.6)*/
{ 1, 0,123,__LINE__, 0xc02024e2, 0x646c5fea, 0xc01f9999, 0x999999a3},	/* -8.07204=f(-7.9)*/
{ 0, 0,123,__LINE__, 0xc0151f76, 0x4398f229, 0xc018cccc, 0xccccccd6},	/* -5.28072=f(-6.2)*/
{ 0, 0,123,__LINE__, 0xc0068132, 0x3a20c799, 0xc0120000, 0x00000009},	/* -2.81308=f(-4.5)*/
{11, 0,123,__LINE__, 0x3fc09d54, 0x275536df, 0xc0066666, 0x66666678},	/* 0.129801=f(-2.8)*/
{ 1, 0,123,__LINE__, 0x40023070, 0x04029559, 0xbff19999, 0x999999bd},	/* 2.27365=f(-1.1)*/
{63, 0,123,__LINE__, 0x3fd97ca9, 0xdd244f01, 0x3fe33333, 0x333332ec},	/* 0.398234=f(0.6)*/
{63, 0,123,__LINE__, 0x3fc3bc7a, 0xe53846b1, 0x40026666, 0x66666654},	/* 0.154189=f(2.3)*/
{63, 0,123,__LINE__, 0x3ffcab0b, 0xfa2a1fd5, 0x400fffff, 0xffffffee},	/* 1.79176=f(4)*/
{63, 0,123,__LINE__, 0x401122c8, 0x6abdedf7, 0x4016cccc, 0xccccccc4},	/* 4.28397=f(5.7)*/
{63, 0,123,__LINE__, 0x401d5c93, 0x1f42284d, 0x401d9999, 0x99999991},	/* 7.3404=f(7.4)*/
{63, 0,123,__LINE__, 0x4025a375, 0x0a6f0adb, 0x40223333, 0x3333332f},	/* 10.8193=f(9.1)*/
{64, 0,123,__LINE__, 0x402d459e, 0xd9f0398a, 0x40259999, 0x99999995},	/* 14.636=f(10.8)*/
{64, 0,123,__LINE__, 0x4032bbfe, 0x32d3aa79, 0x4028ffff, 0xfffffffb},	/* 18.7343=f(12.5)*/
{63, 0,123,__LINE__, 0x40371300, 0x26276f89, 0x402c6666, 0x66666661},	/* 23.0742=f(14.2)*/
{63, 0,123,__LINE__, 0x403ba020, 0x52c704f1, 0x402fcccc, 0xccccccc7},	/* 27.6255=f(15.9)*/
{64, 0,123,__LINE__, 0x40402eaf, 0xef4149f4, 0x40319999, 0x99999997},	/* 32.3647=f(17.6)*/
{64, 0,123,__LINE__, 0x4042a2f9, 0x41f4bf5a, 0x40334ccc, 0xccccccca},	/* 37.2732=f(19.3)*/
{63, 0,123,__LINE__, 0x40452af5, 0x7aed77b9, 0x4034ffff, 0xfffffffd},	/* 42.3356=f(21)*/
{63, 0,123,__LINE__, 0x4047c501, 0x9442501d, 0x4036b333, 0x33333330},	/* 47.5391=f(22.7)*/
{64, 0,123,__LINE__, 0x404a6fba, 0xe04511ae, 0x40386666, 0x66666663},	/* 52.8729=f(24.4)*/
{64, 0,123,__LINE__, 0x404d29f1, 0x436831ba, 0x403a1999, 0x99999996},	/* 58.3277=f(26.1)*/
{64, 0,123,__LINE__, 0x404ff29d, 0x1a191b4b, 0x403bcccc, 0xccccccc9},	/* 63.8954=f(27.8)*/
{64, 0,123,__LINE__, 0x4051646b, 0xd261edc0, 0x403d7fff, 0xfffffffc},	/* 69.5691=f(29.5)*/
{0}
};
void test_gamma(m)   {run_vector_1(m,gamma_vec,(char *)(lgamma),"lgamma","dd");   }	
